smolyak: A Python toolkit for the acceleration of scientific computations
=========================================================================
:Author: Soeren Wolfers <soeren.wolfers@gmail.com>
:Organization: King Abdullah University of Science and Technology (KAUST) 

This Python package provides tools for the non-intrusive acceleration of scientific computations using Smolyak's algorithm.

As special cases, it includes integration and interpolation on sparse grids, as well as multilevel and multi-index algorithms. for stochastic collocation.

For an overview, check out 

   Tempone R., Wolfers S. (2017). `Smolyak's algorithm: A powerful black box for the acceleration of scientific computations`__.
   
.. __: https://arxiv.org/abs/1703.08872 

